==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridToolbarExporterDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExporterEventEventArgsDescriptionMetadata } from "./WebExporterEventEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebBaseToolbarDirectiveDescriptionMetadata } from "./WebBaseToolbarDirectiveDescriptionMetadata";
import { WebGridToolbarExporterDescription } from "./WebGridToolbarExporterDescription";
/**
 * @hidden
 */
export let WebGridToolbarExporterDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarExporterDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarExporterDescriptionMetadata.a == null) {
                WebGridToolbarExporterDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarExporterDescriptionMetadata.c(WebGridToolbarExporterDescriptionMetadata.a);
            }
            if (a.j(WebGridToolbarExporterDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridToolbarExporterDescriptionMetadata.a);
            WebExporterEventEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseToolbarDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarExporter");
            a.item("__tagNameWC", "String:igc-grid-toolbar-exporter");
            a.item("__packageNameWC", "String:grids");
            a.item("__manageItemInMarkup", "Boolean");
            a.item("ExportCSV", "Boolean");
            a.item("ExportExcel", "Boolean");
            a.item("Filename", "String");
            a.item("IsExporting", "Boolean");
            a.item("ExportStartedRef", "EventRef::exportStarted:customEvent");
            a.item("ExportEndedRef", "EventRef::exportEnded:customEvent");
        }
        static d(a) {
            WebGridToolbarExporterDescriptionMetadata.b(a);
            a.aa("WebGridToolbarExporter", () => new WebGridToolbarExporterDescription());
            a.z("WebGridToolbarExporter", WebGridToolbarExporterDescriptionMetadata.a);
        }
    }
    WebGridToolbarExporterDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarExporterDescriptionMetadata, 'WebGridToolbarExporterDescriptionMetadata');
    WebGridToolbarExporterDescriptionMetadata.a = null;
    return WebGridToolbarExporterDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridToolbarExporterDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExporterEventEventArgsDescriptionMetadata } from "./WebExporterEventEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebBaseToolbarDirectiveDescriptionMetadata } from "./WebBaseToolbarDirectiveDescriptionMetadata";
import { WebGridToolbarExporterDescription } from "./WebGridToolbarExporterDescription";
/**
 * @hidden
 */
export let WebGridToolbarExporterDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarExporterDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarExporterDescriptionMetadata.a == null) {
                WebGridToolbarExporterDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarExporterDescriptionMetadata.c(WebGridToolbarExporterDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarExporterDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridToolbarExporterDescriptionMetadata.a);
            WebExporterEventEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseToolbarDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarExporter");
            a.item("__tagNameWC", "String:igc-grid-toolbar-exporter");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("__manageItemInMarkup", "Boolean");
            a.item("ExportCSV", "Boolean");
            a.item("ExportExcel", "Boolean");
            a.item("Filename", "String");
            a.item("IsExporting", "Boolean");
            a.item("ExportStartedRef", "EventRef::exportStarted:customEvent");
            a.item("ExportEndedRef", "EventRef::exportEnded:customEvent");
        }
        static d(a) {
            WebGridToolbarExporterDescriptionMetadata.b(a);
            a.ac("WebGridToolbarExporter", () => new WebGridToolbarExporterDescription());
            a.ab("WebGridToolbarExporter", WebGridToolbarExporterDescriptionMetadata.a);
        }
    }
    WebGridToolbarExporterDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarExporterDescriptionMetadata, 'WebGridToolbarExporterDescriptionMetadata');
    WebGridToolbarExporterDescriptionMetadata.a = null;
    return WebGridToolbarExporterDescriptionMetadata;
})();
